REM TEACHING SCRIPT - Multi picture importer [CorelSCRIPT 8]
REM ClipArtManual.csc  February 5, 1998
REM  1998 Corel Corporation. All rights reserved.

REM **********************************************************************
REM  This script automates the tedious process of importing a large number of
REM  graphics into a Ventura publication. To customize the number of frames that
REM  appear on a page, simply edit the predefined GLOBAL CONST variables that
REM  follow this comment.
REM ***********************************************************************

' Using these constants will produce 16 frames per page; to print 12, change 
' FRAME_WIDTH to 2.0, and COLUMNS_PER_PAGE to 3
GLOBAL CONST ROWS_PER_PAGE& = 4		
GLOBAL CONST COLUMNS_PER_PAGE& = 4
GLOBAL CONST FRAME_WIDTH! = 1.5				'Width of Frame in inches
GLOBAL CONST FRAME_HEIGHT! = 1.8				'Height of Frame in inches

' This section declares the file types to print, and where they are located
GLOBAL CONST FILE_TYPE$ = "bmp"				' 2 or 3 letter extension of the file type to embed
GLOBAL CONST DEFAULT_DIRECTORY$ = "C:\Win95\"	' Ensure Directory ends in a backslash character
GLOBAL CONST HIDE_PICTURES&  = TRUE			' Hiding the pictures makes the script run faster

' This section lets the system know what subroutines we will be calling
DECLARE SUB CreateFrame(FileName$, FrameIndex&, Directory$)
DECLARE SUB CreateNewPage
DECLARE SUB Initialize
DECLARE SUB CreateCaptionTag
DECLARE FUNCTION FilterTypeFromExtension&(FileType$)

' This section defines some values that will be used further down into the script
GLOBAL CONST OBJECT_VENTURA$ = "CorelVentura.Automation.8"	' For ease of porting to VP8
GLOBAL CONST COLUMN_OFFSET! = 0.3				' Space between columns, in inches
GLOBAL CONST ROW_OFFSET! = 0.2				' Space between rows, in inches
GLOBAL CONST COLUMN_START! = 1.0				' Margin to left of 1st column, in inches
GLOBAL CONST ROW_START! = 1.0					' Margin above the 1st row, in inches

'This section defines some values specifying the type of file to be used [used by FINDFIRSTFOLDER() function]
#DEFINE FILEATTR_READ_ONLY     1				' Specifies Read-only files
#DEFINE FILEATTR_HIDDEN        2				' Specifies Hidden files
#DEFINE FILEATTR_SYSTEM        4				' Specifies System files
#DEFINE FILEATTR_ARCHIVE       32				' Specifies Archive files
#DEFINE FILEATTR_NORMAL_FILE   128				' Specifies Normal files


'//// MAIN //////////////////////////////////////////////////////////////////
FilterType& = FilterTypeFromExtension(FILE_TYPE$) 		' Set the filter type based upon the users choice above
SourceDir$ = GETFOLDER(DEFAULT_DIRECTORY$)				' Query the user for the folder to use...

IF SourceDir$ <> "" THEN 
	SourceDir$ = SourceDir$ & "\" 					' Make SourceDir end with a backslash
	Initialize									' Initialize Ventura settings

	File$ = FINDFIRSTFOLDER(SourceDir$ & "*." & FILE_TYPE$, FILEATTR_READ_ONLY OR FILEATTR_HIDDEN OR FILEATTR_SYSTEM OR FILEATTR_ARCHIVE OR FILEATTR_NORMAL_FILE)
	DO WHILE File$ <> ""
		FrameIndex& = FrameIndex&+1
		CreateFrame File$, FrameIndex&, SourceDir$
		IF FrameIndex = (ROWS_PER_PAGE& * COLUMNS_PER_PAGE&) THEN 
			' This page is full, we need to create a new page...
			FrameIndex& = 0
			CreateNewPage
		ENDIF
		File$ = FINDNEXTFOLDER()
	LOOP 
ENDIF


' **************************************************************************************
' CreateFrame
' This subroutine creates the frames for the imported clipart pictures.
'
' PARAMS: FileName$ - the name of the clipart file to import.
'         FrameIndex& -  indicates current frame being drawn.
' 		Directory$ - the name of the directory where the clipart resides
' **************************************************************************************
SUB CreateFrame(FileName$, FrameIndex&, Directory$)
ON ERROR GOTO ErrorHandler
CaptionHeight! = FRAME_HEIGHT! * .2
FrameColSpacing! = FRAME_WIDTH + COLUMN_OFFSET
FrameRowSpacing! = FRAME_HEIGHT! + ROW_OFFSET + CaptionHeight!

	WITHOBJECT OBJECT_VENTURA
		' Now place each file in a frame...
		Row% = FIX((FrameIndex&-1)/COLUMNS_PER_PAGE)
		Col% = FIX((FrameIndex&-1) MOD COLUMNS_PER_PAGE) 
		leftedge# = (FROMINCHES(COLUMN_START + (Col% * FrameColSpacing!)))
		topedge# = (FROMINCHES(ROW_START + (Row% * FrameRowSpacing!))) 
		.FormatCreateFrame leftedge#, topedge#, FROMINCHES(FRAME_WIDTH),FROMINCHES(FRAME_HEIGHT)
		.FormatFrameMarginsInside 0, 0, 0, 0
		.FormatFrameMarginsOutside 0, 0, 0, 0
		.FormatFrameGeneral .CaptionType=2, .FrameFlow = 2
		.FileImportPicture Directory$ & FileName$, FilterType, FALSE, TRUE
		.FormatFramePicture .FitInFrame=TRUE, .MaintainAspect=TRUE
		.FrameFirst FALSE, .FrameCount()
		.FormatFrameGeneral , , FROMINCHES(FRAME_WIDTH),FROMINCHES(CaptionHeight!)
		.FormatFrameMarginsInside 0, 0, 0, 0
		.FormatFrameMarginsOutside 0, 0, 0, 0
		.FrameFirstLine
		.FormatSetParaTag "caption"
		.TypeText LEFT(FileName$, INSTR(FileName$, ".")-1)
	END WITHOBJECT
ErrorHandler:
END SUB


' **************************************************************************************
' Initialize
' This subroutine initializes Ventura, opens a new file and creates any required
' paragraph tags
' **************************************************************************************
SUB Initialize
	WITHOBJECT OBJECT_VENTURA
		.SetVisible TRUE
		.FileNew
		.ViewPageFooter FALSE
		.ViewPageHeader FALSE
		.ViewFrameBorders TRUE
		.ViewHideAllGraphics HIDE_PICTURES
		.ViewZoom 50
	END WITHOBJECT	
	CreateCaptionTag
END SUB


' **************************************************************************************
' CreateCaptionTag
' This subroutine creates a tag for the caption
' **************************************************************************************
SUB CreateCaptionTag
	WITHOBJECT OBJECT_VENTURA
		.PageFirstLine 			' Must move onto the page to be able to create the new tag
		.ParaTagAddNew "caption"		' Create "caption", and give it the desired attributes
		.FormatParaTagBegin "caption"
		.FormatParaAlignment  1, 0, FALSE, 0, 0, 0, 0, 1, 0, FALSE, FROMINCHES(3.0), 46, 0
		.FormatParaBreaks  0, 0, 1, FALSE, TRUE, FALSE, FALSE
		.FormatParaColor FALSE, 2, 0, 0, 0, 100, FALSE, FALSE
		.FormatParaDefaults TRUE, 1, , FROMPOINTS(56), FROMPOINTS(9.56), FROMPOINTS(56), FROMPOINTS(3.0), FROMPOINTS(56), FROMPOINTS(56), FROMPOINTS(56), FROMPOINTS(1.69), 8, FROMPOINTS(4.7), 8, FROMPOINTS(1.10)
		.FormatParaEffects  0
		.FormatParaFont "Times New Roman", 7, 400, FALSE, 0, FALSE, FALSE, FALSE
		.FormatParaHyphenation FALSE, "US English", 2, 5, 2, 2, TRUE, TRUE, FALSE
		.FormatParaSpacing  0, 0, FROMPOINTS(6.0), 0, 1, FALSE, FALSE, FALSE, 0, FROMPOINTS(144)
		.FormatParaTypography  1000, 600, 2000, FALSE, 0, FROMPOINTS(13.97), FROMPOINTS(13.97), 0, FALSE
		.FormatParaTagEnd
	END WITHOBJECT	
END SUB


' **************************************************************************************
' CreateNewPage
' This subroutine inserts a new page and makes the new page the active page.
' **************************************************************************************
SUB CreateNewPage
	WITHOBJECT OBJECT_VENTURA
		CurrentPage& = .CurrentPageNumber()
		.PageInsertPages , 1		'insert a new page
		.ViewGoToPage CurrentPage&+1 
	END WITHOBJECT	
END SUB


' **************************************************************************************
' FilterTypeFromExtension
' This subroutine returns a filter type based upon the extension
' This is a handy general-purpose function that you may want to re-use
' Other FILTER_TYPE ids can be found by looking in the help file under
' the FileImportPicture automation command.
' **************************************************************************************
FUNCTION FilterTypeFromExtension&(FileType$)
	SELECT CASE LCASE(FileType$)
		CASE "bmp"
			FILTER_TYPE& = 1
		CASE "cmx"
			FILTER_TYPE& = 102
		CASE "gif"
			FILTER_TYPE& = 5
		CASE "jpg"
			FILTER_TYPE& = 6
		CASE "pcd"
			FILTER_TYPE& = 7
		CASE "eps"
			FILTER_TYPE& = 40
		CASE "ai"
			FILTER_TYPE& = 34
	END SELECT
END FUNCTION

