REM Finds unused tags in Corel VENTURA publications [CorelSCRIPT 8]
REM FindUnusedTags.csc  February 20, 1998
REM  1998 Corel Corporation. All rights reserved.

REM **************************************************************************************
REM This script searches the open VENTURA publication for unused tags - 
REM paragraph, character, and frame tags.
REM The user is prompted for the type of tag to search for (or all).
REM If a publication is not open, the user is prompted to open one or exit the wizard.
REM A list of unused tags is displayed (different tags types are displayed separately)
REM The user has the option of saving this list to a file, or deleting all unused tags, 
REM or just leaving them alone.
REM **************************************************************************************

' Create a temporary folder to provide a path for the include files
'  -this enables the include files to be located 
#addfol "..\..\Scripts"
#include "ScpConst.csi"
#include "VPConst.csi"

' Embed bitmaps if script is to be compiled into exe or csb formats
' -this will eliminate the need to include these files
#ADDRESBMP IntroBMP "Bitmaps\IntroBMP.bmp"
#ADDRESBMP Step2BMP "Bitmaps\Step2BMP.bmp"
#ADDRESBMP LastBMP "Bitmaps\LastBMP.bmp"

'Constants for Dialog Return Values
GLOBAL CONST DIALOG_RETURN_CANCEL% = 2
GLOBAL CONST DIALOG_RETURN_NEXT% = 3
GLOBAL CONST DIALOG_RETURN_BACK% = 4
GLOBAL CONST DIALOG_RETURN_BROWSE% = 5

'Constants for the different tag types
GLOBAL CONST PARA_TAG% = 1
GLOBAL CONST CHAR_TAG% = 2
GLOBAL CONST FRAME_TAG% = 3

'Constant for the initial size of the arrays holding the unused tags lists
GLOBAL CONST MAXTAGS% = 100		'Maximum number of tags

'/////FUNCTION & SUBROUTINE DECLARATIONS/////////////////////////////////////////////////
DECLARE SUB RegQuery()
DECLARE FUNCTION ShowIntro() AS INTEGER
DECLARE FUNCTION GetTagType() AS INTEGER
DECLARE FUNCTION ShowUnusedTags%(TagType%)
DECLARE FUNCTION ShowFinish() AS INTEGER
DECLARE FUNCTION RemoveTags(TagType%) AS INTEGER
DECLARE FUNCTION SaveToFile(TagFile$) AS BOOLEAN
DECLARE SUB FindParaTags()
DECLARE SUB FindCharTags()
DECLARE SUB FindFrameTags()
DECLARE SUB CreateListOfTags(TypeOfTag&, NameOfTag AS STRING)


'/////GLOBAL VARIABLES & CONSTANTS////////////////////////////////////////////////////////
GLOBAL VenturaRoot$						'Root directory of Ventura from registry
GLOBAL TagType%						'Type of tag to search for (1-PARA; 2-CHAR; 3-FRAME; 4-LINE; 5-PAGE)

GLOBAL UnusedParaTags$(MAXTAGS%)			'List of unused paragraph tags
GLOBAL UnusedParaTagsCount%				'Total number of unused paragraph tags
GLOBAL SelectedUnusedParaTags$(MAXTAGS%)	'List of unused paragraph tags selected for deletion
GLOBAL SelectedUnusedParaTagsCount%		'Total number of paragraph tags selected for deletion

GLOBAL UnusedCharTags$(MAXTAGS%)			'List of unused character tags
GLOBAL UnusedCharTagsCount%				'Total number of unused character tags
GLOBAL SelectedUnusedCharTags$(MAXTAGS%)	'List of unused character tags selected for deletion
GLOBAL SelectedUnusedCharTagsCount%		'Total number of character tags selected for deletion

GLOBAL UnusedFrameTags$(MAXTAGS%)			'List of unused frame tags
GLOBAL UnusedFrameTagsCount%				'Total number of unused frame tags
GLOBAL SelectedUnusedFrameTags$(MAXTAGS%)	'List of unused frame tags selected for deletion
GLOBAL SelectedUnusedFrameTagsCount%		'Total number of frame tags selected for deletion

GLOBAL FindParaTag%		: FindParaTag%=1	'Flag used to define search;IF set to 1, find para tags; ELSE don't
GLOBAL FindCharTag%		': FindCharTag%=1	'Flag used to define search;IF set to 1, find char tags; ELSE don't
GLOBAL FindFrameTag%	': FindFrameTag%=1	'Flag used to define search;IF set to 1, find frame tags; ELSE don't

GLOBAL TypeOfTag$(5)	'list of the different types of tags
TypeOfTag$(PARA_TAG%) = "Paragraph"
TypeOfTag$(CHAR_TAG%) = "Character"
TypeOfTag$(FRAME_TAG%) = "Frame"

'/////LOCAL DECLARATIONS//////////////////////////////////////////////////////////////////
CONST MAXSTEP% = 7		'maximum number of pages in the Wizard
DIM DialogReturn%		'identifies user's selection for next step in Wizard
DIM NextStep%			'specifies which page appears next in the Wizard


' **************************************************************************************
' MAIN
' **************************************************************************************
ON ERROR GOTO ErrorHandler
RegQuery				'get root directory where Ventura is installed

NextStep% = 1
DO
	SELECT CASE NextStep%
		CASE 1: DialogReturn% = ShowIntro()		'Show Intro dialog

		CASE 2: DialogReturn% = GetTagType()		'Get tag type (para, char, frame, line)
 			IF FindParaTag% AND UnusedParaTagsCount% < 1 THEN FindParaTags	'Get list of unused para tags
 			IF FindCharTag% AND UnusedCharTagsCount% < 1 THEN FindCharTags	'Get list of unused char tags
 			IF FindFrameTag% AND UnusedFrameTagsCount% < 1 THEN FindFrameTags'Get list of unused frame tags

		CASE 3
			IF FindParaTag% AND UnusedParaTagsCount% > 0 THEN 		'Display list of unused paragraph tags
				TagType% = PARA_TAG	
				DialogReturn% = ShowUnusedTags(PARA_TAG)	
			ENDIF
		CASE 4 
			IF FindCharTag% AND UnusedCharTagsCount% > 0 THEN 		'Display list of unused character tags
				TagType% = CHAR_TAG
				DialogReturn% = ShowUnusedTags(CHAR_TAG)	
			ENDIF
		CASE 5 
			IF FindFrameTag% AND UnusedFrameTagsCount% > 0 THEN 		'Display list of unused frame tags 
				TagType% = FRAME_TAG
				DialogReturn% = ShowUnusedTags(FRAME_TAG)	
			ENDIF

		CASE 6: DialogReturn% = ShowFinish()

		CASE 7 
			IF FindParaTag% THEN DialogReturn% = RemoveTags(PARA_TAG)	
			IF FindCharTag% THEN DialogReturn% = RemoveTags(CHAR_TAG)	
			IF FindFrameTag% THEN DialogReturn% = RemoveTags(FRAME_TAG)	
			NextStep% = NextStep% + 1
	END SELECT

	NextStep% = NextStep% + DialogReturn%
LOOP UNTIL NextStep% = MAXSTEP + 1

ExitScript:
STOP

ErrorHandler:
SELECT CASE ErrNum
	CASE 800
		MESSAGE "FATAL ERROR" & CHR(13) & "Script will now exit."
		RESUME AT ExitScript
	CASE ELSE
		MESSAGE "ERROR: " & STR(ErrNum) & CHR(13) & "Script will now exit."
		RESUME AT ExitScript
	END SELECT


' **************************************************************************************
' RegQuery
' This subroutine queries the Registry to determine the root directory where Ventura is installed
' **************************************************************************************
SUB RegQuery
ON ERROR GOTO ErrorHandler
	VentDir$ = REGISTRYQUERY(HKEY_LOCAL_MACHINE,VENTURA_REGQUERY_CONST,"ConfigDir") 	'Root directory where Ventura is installed
	
	first% = 1
	pos% = 1
	DO WHILE first <> 0
	    first = INSTR(VentDir$, "\", first )
	    IF first <> 0 THEN
	        pos = first
	        first = first + 1
	    END IF
	LOOP
	VenturaRoot$ = LEFT(VentDir$, pos - 1) 'Root directory where Visual CADD is installed

EXIT SUB
ErrorHandler:
	MESSAGE "Error reading registry:" & CHR(13) & RegString$
	ErrNum = 800
END SUB



' **************************************************************************************
' ShowIntro
' This function displays the introduction dialog.
' 
' PARAMS: None
'
' RETURNS: ShowIntro AS INTEGER - Integer indicating dialog return value(user selection)
' **************************************************************************************
FUNCTION ShowIntro%
BEGIN DIALOG OBJECT IntroDialog 290, 180, "Find Unused Tags Wizard ", SUB IntroDialogEventHandler
	PUSHBUTTON  181, 160, 46, 14, .NextButton, "&Next >"
	CANCELBUTTON  234, 160, 46, 14, .CancelButton
	PUSHBUTTON  135, 160, 46, 14, .BackButton, "< &Back"
	TEXT  95, 10, 185, 20, .Text2, "This Wizard locates and deletes all the unused tags in the current publication."
	TEXT  95, 129, 185, 12, .Text3, "To begin finding unused tags, click Next."
	IMAGE  10, 10, 75, 130, .IntroImage
	GROUPBOX  10, 150, 270, 5, .LineGroupBox
	TEXT  95, 30, 185, 27, .Text1, "Note - default tags which cannot be deleted are not listed."
END DIALOG

	IntroDialog.IntroImage.SetImage "#IntroBMP"
	IntroDialog.IntroImage.SetStyle STYLE_IMAGE_CENTERED
	IntroDialog.SetStyle STYLE_INVISIBLE

	IntroRet%=DIALOG(IntroDialog)
	IF IntroRet% = DIALOG_RETURN_CANCEL THEN STOP	
	IF IntroRet% = DIALOG_RETURN_NEXT THEN ShowIntro% = 1		
END FUNCTION

' **************************************************************************************
' IntroDialogEventHandler
' This subroutine handles events for the Intro dialog.
' PARAMS: BYVAL ControlID% - Integer indicating the dialog control that is generating a dialog event.
'		BYVAL Event% - Integer indicating the dialog event that has occurred in the dialog box
' **************************************************************************************
SUB IntroDialogEventHandler(BYVAL ControlID%, BYVAL Event%)
	IF Event% = EVENT_INITIALIZATION THEN 		
		IntroDialog.BackButton.Enable FALSE 
		IntroDialog.SetStyle STYLE_VISIBLE
	ENDIF
	IF Event% = EVENT_MOUSE_CLICK THEN 	
		SELECT CASE ControlID%
			CASE IntroDialog.NextButton.GetID()
				IntroDialog.CloseDialog DIALOG_RETURN_NEXT
			CASE IntroDialog.CancelButton.GetID()
				IntroDialog.CloseDialog DIALOG_RETURN_CANCEL
		END SELECT
	ENDIF
END FUNCTION



' **************************************************************************************
' GetTagType
' This function displays the tag type dialog and prompts the user for the type of tag 
' to look for (paragraph, character, frame, page, rule).
' 
' PARAMS: None
'
' RETURNS: GetTagType AS INTEGER - Integer indicating dialog return value(user selection)
' **************************************************************************************
FUNCTION GetTagType%

BEGIN DIALOG OBJECT TagTypeDialog 290, 180, "Find Unused Tags Wizard", SUB TagTypeDialogEventHandler
	CHECKBOX  115, 45, 145, 10, .ParaTagCheckBox, "&Paragraph Tags"
	CHECKBOX  115, 60, 145, 10, .CharTagCheckBox, "&Character Tags"
	CHECKBOX  115, 75, 145, 10, .FrameTagCheckBox, "&Frame Tags"
	PUSHBUTTON  223, 109, 46, 14, .AllButton, "Select &All"
	PUSHBUTTON  135, 160, 46, 14, .BackButton, "< &Back"
	PUSHBUTTON  181, 160, 46, 14, .NextButton, "&Search"
	CANCELBUTTON  234, 160, 46, 14, .CancelButton
	TEXT  95, 10, 185, 12, .Text1, "What type of tags would you like to search for?"
	GROUPBOX  95, 28, 185, 103, .GroupBox1, "Tag Type:"
	IMAGE  10, 10, 75, 130, .TagTypeImage
	GROUPBOX  10, 150, 270, 5, .LineGroupBox
END DIALOG

	TagTypeDialog.SetStyle STYLE_INVISIBLE
	TagTypeDialog.TagTypeImage.SetImage "#Step2BMP"
	TagTypeDialog.TagTypeImage.SetStyle STYLE_IMAGE_CENTERED

	TagTypeRet%=DIALOG(TagTypeDialog)
	SELECT CASE TagTypeRet%
		CASE DIALOG_RETURN_CANCEL	
			STOP
		CASE DIALOG_RETURN_NEXT		
			TagTypeDialog.SetVisible FALSE
			GetTagType = 1
		CASE DIALOG_RETURN_BACK		
			GetTagType = -1
	END SELECT

END FUNCTION

' **************************************************************************************
' TagTypeDialogEventHandler
' This subroutine handles events for the tag type dialog.
' PARAMS: BYVAL ControlID% - Integer indicating the dialog control that is generating a dialog event.
'		BYVAL Event% - Integer indicating the dialog event that has occurred in the dialog box
' **************************************************************************************
SUB TagTypeDialogEventHandler(BYVAL ControlID%, BYVAL Event%)
	IF Event% = EVENT_INITIALIZATION  THEN		
		TagTypeDialog.SetStyle STYLE_VISIBLE
		TagTypeDialog.ParaTagCheckBox.SetThreeState FALSE
		TagTypeDialog.CharTagCheckBox.SetThreeState FALSE
		TagTypeDialog.FrameTagCheckBox.SetThreeState FALSE
		TagTypeDialog.ParaTagCheckBox.SetValue FindParaTag%
		TagTypeDialog.CharTagCheckBox.SetValue FindCharTag%
		TagTypeDialog.FrameTagCheckBox.SetValue FindFrameTag%
	ENDIF

	IF Event% = EVENT_MOUSE_CLICK THEN 		
		SELECT CASE ControlID%
			CASE TagTypeDialog.ParaTagCheckBox.GetID()
				FindParaTag% = TagTypeDialog.ParaTagCheckBox.GetValue()
			CASE TagTypeDialog.CharTagCheckBox.GetID()
				FindCharTag% = TagTypeDialog.CharTagCheckBox.GetValue()
			CASE TagTypeDialog.FrameTagCheckBox.GetID()
				FindFrameTag% = TagTypeDialog.FrameTagCheckBox.GetValue()
			CASE TagTypeDialog.AllButton.GetID()
				FindParaTag%=1		:	TagTypeDialog.ParaTagCheckBox.SetValue FindParaTag%
				FindCharTag%=1		:	TagTypeDialog.CharTagCheckBox.SetValue FindCharTag%
				FindFrameTag%=1	:	TagTypeDialog.FrameTagCheckBox.SetValue FindFrameTag%

			CASE TagTypeDialog.NextButton.GetID()
				BEGINWAITCURSOR
				WITHOBJECT OBJECT_VENTURA8
				ENDWAITCURSOR
					'Make sure there is an open pub
					IF .CountWindows() = 0 THEN
						PubMsg$ = "You need an open publication to run this script." & CHR(13) & "Open one now?"
						MsgVal% = MESSAGEBOX(PubMsg$, "WARNING", MB_YES_NO OR MB_STOP_ICON)
						IF MsgVal% = MSG_YES THEN 		'Yes, open a pub
							SETCURRFOLDER VenturaRoot$
							PubName$ = GETFILEBOX("Publication files (*.VP*)|*.VP*", , , ,"*.vp*", VenturaRoot$ & "\Ventura\Samples" )
							IF PubName$ <> "" THEN
								.SetVisible TRUE
								.FileOpen PubName$, , TRUE, 1, TRUE, FALSE
								TagTypeDialog.closedialog DIALOG_RETURN_NEXT
							ENDIF
						ELSE
							'STOP
						ENDIF
					ELSE
						PubName$=.PublicationName()
						TagTypeDialog.closedialog DIALOG_RETURN_NEXT
					ENDIF
				END WITHOBJECT

			CASE TagTypeDialog.BackButton.GetID()		
				TagTypeDialog.closedialog DIALOG_RETURN_BACK
			CASE TagTypeDialog.CancelButton.GetID()		
				TagTypeDialog.closedialog DIALOG_RETURN_CANCEL	
		END SELECT
	ENDIF

END SUB


' **************************************************************************************
' ShowUnusedTags
' This function displays the results of the unused tags search.
' 
' PARAMS:
'
' RETURNS: ShowParaTag AS INTEGER - Integer indicating dialog return value(user selection)
' **************************************************************************************
FUNCTION ShowUnusedTags%(TagType%)
BEGIN DIALOG OBJECT UnusedTagsDialog 290, 180, "Find Unused Tags Wizard", SUB UnusedTagsDialogEventHandler	 '"Corel VENTURA Conversion Wizard - Done"
	LISTBOX  10, 35, 100, 110, .TagsListBox
	PUSHBUTTON  122, 40, 46, 14, .SelectButton, "Se&lect >>"
	PUSHBUTTON  122, 55, 46, 14, .DeselectButton, "<< &Deselect"
	PUSHBUTTON  122, 85, 46, 14, .SelectAllButton, "Select &All"
	PUSHBUTTON  122, 100, 46, 14, .DeselectAllButton, "D&eselect All"
	PUSHBUTTON  122, 125, 46, 14, .SaveButton, "&Save List..."
	LISTBOX  180, 35, 100, 110, .SelectedTagsListBox
	PUSHBUTTON  135, 160, 46, 14, .BackButton, "< &Back"
	PUSHBUTTON  181, 160, 46, 14, .NextButton, "&Next >"
	CANCELBUTTON  234, 160, 46, 14, .CancelButton
	TEXT  10, 5, 269, 12, .Text2, ""
	TEXT  10, 20, 79, 12, .Text4, ""
	TEXT  90, 20, 20, 12, .TagsCountText, ""
	TEXT  180, 20, 75, 12, .Text5, "Tags to be deleted:"
	TEXT  258, 20, 20, 12, .SelectedTagsCountText, ""
	GROUPBOX  10, 150, 270, 5, .LineGroupBox
END DIALOG
	
	UnusedTagsDialog.SetStyle STYLE_INVISIBLE
	UnusedTagsDialogRet% = DIALOG(UnusedTagsDialog)
	SELECT CASE UnusedTagsDialogRet%
		CASE DIALOG_RETURN_CANCEL		
			STOP
		CASE DIALOG_RETURN_NEXT		
			ShowUnusedTags = 1		'proceed to next dialog page
		CASE DIALOG_RETURN_BACK 		
			ShowUnusedTags = -1		'return to previous dialog page
	END SELECT
	
END FUNCTION


' **************************************************************************************
' UnusedTagsDialogEventHandler
' This subroutine handles events for the para tag dialog.
' PARAMS: BYVAL ControlID% - Integer indicating the dialog control that is generating a dialog event.
'		BYVAL Event% - Integer indicating the dialog event that has occurred in the dialog box
' **************************************************************************************
SUB UnusedTagsDialogEventHandler(BYVAL ControlID%, BYVAL Event%)
DIM i%
DIM SaveStatus AS BOOLEAN
STATIC SelectedUnusedTags$(100)
STATIC UnusedTags(100)
STATIC SelectedUnusedTagsCount%
STATIC UnusedTagsCount%

	IF Event% = EVENT_INITIALIZATION THEN 		
		UnusedTagsDialog.TagsCountText.SetStyle STYLE_RIGHT_JUSTIFY
		UnusedTagsDialog.SelectedTagsCountText.SetStyle STYLE_RIGHT_JUSTIFY

		UnusedTagsDialog.Text2.SetText "Which " & TypeOfTag$(TagType%) & " tags would you like to delete?"
		UnusedTagsDialog.Text4.SetText "Unused " & TypeOfTag$(TagType%) & " tags:"

		SELECT CASE TagType%
			CASE PARA_TAG%
				UnusedTagsCount% = UnusedParaTagsCount%
				SelectedUnusedTagsCount% = SelectedUnusedParaTagsCount%
				FOR i% = 1 TO UnusedTagsCount%
					UnusedTagsDialog.TagsListBox.AddItem UnusedParaTags(i%)
				NEXT i%
				FOR i% = 1 TO SelectedUnusedTagsCount%
					UnusedTagsDialog.SelectedTagsListBox.AddItem SelectedUnusedParaTags(i%)
				NEXT i%

			CASE CHAR_TAG%
				UnusedTagsCount% = UnusedCharTagsCount%
				SelectedUnusedTagsCount% = SelectedUnusedCharTagsCount%
				FOR i% = 1 TO UnusedTagsCount%
					UnusedTagsDialog.TagsListBox.AddItem UnusedCharTags(i%)
				NEXT i%
				FOR i% = 1 TO SelectedUnusedTagsCount%
					UnusedTagsDialog.SelectedTagsListBox.AddItem SelectedUnusedCharTags(i%)
				NEXT i%

			CASE FRAME_TAG%
				UnusedTagsCount% = UnusedFrameTagsCount%
				SelectedUnusedTagsCount% = SelectedUnusedFrameTagsCount%
				FOR i% = 1 TO UnusedTagsCount%
					UnusedTagsDialog.TagsListBox.AddItem UnusedFrameTags(i%)
				NEXT i%
				FOR i% = 1 TO SelectedUnusedTagsCount%
					UnusedTagsDialog.SelectedTagsListBox.AddItem SelectedUnusedFrameTags(i%)
				NEXT i%
				
		END SELECT

		IF UnusedTagsCount < 1 THEN
			UnusedTagsDialog.SelectButton.Enable FALSE
			UnusedTagsDialog.DeselectButton.Enable FALSE
			UnusedTagsDialog.SelectAllButton.Enable FALSE
			UnusedTagsDialog.DeselectAllButton.Enable FALSE
			UnusedTagsDialog.SaveButton.Enable FALSE
			UnusedTagsDialog.Text2.SetText "There are no unused " & TypeOfTag$(TagType%) & " tags."
		ENDIF

		UnusedTagsDialog.TagsListBox.SetSelect 1
		UnusedTagsDialog.TagsCountText.SetText UnusedTagsDialog.TagsListBox.GetItemCount()
		UnusedTagsDialog.SelectedTagsCountText.SetText UnusedTagsDialog.SelectedTagsListBox.GetItemCount()
		UnusedTagsDialog.SetStyle STYLE_VISIBLE
	ENDIF

	IF Event% = EVENT_MOUSE_CLICK THEN 	
		SELECT CASE ControlID%

			CASE UnusedTagsDialog.NextButton.GetID()		
				'build list of appropriate tags
				SELECT CASE TagType%
					CASE PARA_TAG%
						SelectedUnusedParaTagsCount% = UnusedTagsDialog.SelectedTagsListBox.GetItemCount()
						REDIM SelectedUnusedParaTags$(SelectedUnusedParaTagsCount)							'redimension array to accomodate all selected files
						FOR i% = 1 TO SelectedUnusedParaTagsCount%									'FOR all items in selected files list
							SelectedUnusedParaTags$(i%) = UnusedTagsDialog.SelectedTagsListBox.GetItem(i%)	'add selection to FilesList
						NEXT i%
						UnusedParaTagsCount% = UnusedTagsDialog.TagsListBox.GetItemCount()
						REDIM UnusedParaTags$(UnusedParaTagsCount)							'redimension array to accomodate all selected files
						FOR i% = 1 TO UnusedParaTagsCount%									'FOR all items in selected files list
							UnusedParaTags$(i%) = UnusedTagsDialog.TagsListBox.GetItem(i%)	'add selection to FilesList
						NEXT i%

					CASE CHAR_TAG%
						SelectedUnusedCharTagsCount% = UnusedTagsDialog.SelectedTagsListBox.GetItemCount()
						REDIM SelectedUnusedCharTags$(SelectedUnusedCharTagsCount)							'redimension array to accomodate all selected files
						FOR i% = 1 TO SelectedUnusedCharTagsCount%									'FOR all items in selected files list
							SelectedUnusedCharTags$(i%) = UnusedTagsDialog.SelectedTagsListBox.GetItem(i%)	'add selection to FilesList
						NEXT i%
						UnusedCharTagsCount% = UnusedTagsDialog.TagsListBox.GetItemCount()
						REDIM UnusedCharTags$(UnusedCharTagsCount)							'redimension array to accomodate all selected files
						FOR i% = 1 TO UnusedCharTagsCount%									'FOR all items in selected files list
							UnusedCharTags$(i%) = UnusedTagsDialog.TagsListBox.GetItem(i%)	'add selection to FilesList
						NEXT i%
		
					CASE FRAME_TAG%
						SelectedUnusedFrameTagsCount% = UnusedTagsDialog.SelectedTagsListBox.GetItemCount()
						REDIM SelectedUnusedFrameTags$(SelectedUnusedFrameTagsCount)							'redimension array to accomodate all selected files
						FOR i% = 1 TO SelectedUnusedFrameTagsCount%									'FOR all items in selected files list
							SelectedUnusedFrameTags$(i%) = UnusedTagsDialog.SelectedTagsListBox.GetItem(i%)	'add selection to FilesList
						NEXT i%
						UnusedFrameTagsCount% = UnusedTagsDialog.TagsListBox.GetItemCount()
						REDIM UnusedFrameTags$(UnusedFrameTagsCount)							'redimension array to accomodate all selected files
						FOR i% = 1 TO UnusedFrameTagsCount%									'FOR all items in selected files list
							UnusedFrameTags$(i%) = UnusedTagsDialog.TagsListBox.GetItem(i%)	'add selection to FilesList
						NEXT i%

				END SELECT

				UnusedTagsDialog.CloseDialog DIALOG_RETURN_NEXT


			CASE UnusedTagsDialog.BackButton.GetID()		
				UnusedTagsDialog.closedialog DIALOG_RETURN_BACK

			CASE UnusedTagsDialog.SelectButton.GetID()			'tags list
				indx% = UnusedTagsDialog.TagsListBox.GetSelect()									'get index of selection
				IF indx%=0 THEN	'no tags selected
					IF UnusedTagsDialog.TagsListBox.GetItemCount() = 0 THEN
						MESSAGE "There are no tags available for selection."
					ELSE
						MESSAGE "Please select a tag from the available tags list."
					ENDIF
				ELSE
					UnusedTagsDialog.SelectedTagsListBox.AddItem UnusedTagsDialog.TagsListBox.GetItem(indx%)	'add selection to SelectedFilesList
					UnusedTagsDialog.TagsListBox.RemoveItem indx%										'remove selection from available files list
					IF indx% > UnusedTagsDialog.TagsListBox.GetItemCount() THEN
						UnusedTagsDialog.TagsListBox.SetSelect indx%-1
					ELSE
						UnusedTagsDialog.TagsListBox.SetSelect indx%
					ENDIF
					UnusedTagsDialog.SelectedTagsListBox.SetSelect 0
				ENDIF

			CASE UnusedTagsDialog.DeselectButton.GetID()			'selected files list
				indx% = UnusedTagsDialog.SelectedTagsListBox.GetSelect()								'get index of selection
				IF indx%=0 THEN	'no files selected
					IF UnusedTagsDialog.SelectedTagsListBox.GetItemCount() = 0 THEN
						MESSAGE "There are no tags available for deselection"
					ELSE
						MESSAGE "Please select a tag from the selected tags list."
					ENDIF
				ELSE
					UnusedTagsDialog.TagsListBox.AddItem UnusedTagsDialog.SelectedTagsListBox.GetItem(indx%)	'add selection to FilesList
					UnusedTagsDialog.SelectedTagsListBox.RemoveItem indx%								'remove selection from selected files list
					IF indx% > UnusedTagsDialog.SelectedTagsListBox.GetItemCount() THEN
						UnusedTagsDialog.SelectedTagsListBox.SetSelect indx%-1
					ELSE
						UnusedTagsDialog.SelectedTagsListBox.SetSelect indx%
					ENDIF
					UnusedTagsDialog.TagsListBox.SetSelect 0
				ENDIF

			CASE UnusedTagsDialog.SelectAllButton.GetID()		
				UnusedTagsDialog.SelectedTagsListBox.SetSelect 0
				WHILE UnusedTagsDialog.TagsListBox.GetItemCount() > 0		'while there are available files
					UnusedTagsDialog.SelectedTagsListBox.AddItem UnusedTagsDialog.TagsListBox.GetItem(1)	'add selection to SelectedFilesList
					UnusedTagsDialog.TagsListBox.RemoveItem 1											'remove selection from available files list	
					UnusedTagsDialog.TagsCountText.SetText UnusedTagsDialog.TagsListBox.GetItemCount()		'number of available files
					UnusedTagsDialog.SelectedTagsCountText.SetText UnusedTagsDialog.SelectedTagsListBox.GetItemCount()	'number of selected files
				WEND

			CASE UnusedTagsDialog.DeselectAllButton.GetID()		
				UnusedTagsDialog.TagsListBox.SetSelect 0
				WHILE UnusedTagsDialog.SelectedTagsListBox.GetItemCount() > 0		'while there are selected files
					UnusedTagsDialog.TagsListBox.AddItem UnusedTagsDialog.SelectedTagsListBox.GetItem(1)	'add selection to FilesList
					UnusedTagsDialog.SelectedTagsListBox.RemoveItem 1									'remove selection from selected files list
					UnusedTagsDialog.TagsCountText.SetText UnusedTagsDialog.TagsListBox.GetItemCount()		'number of available files
					UnusedTagsDialog.SelectedTagsCountText.SetText UnusedTagsDialog.SelectedTagsListBox.GetItemCount()		'number of selected files
				WEND

			CASE UnusedTagsDialog.SaveButton.GetID()		
				DialogTitle$ = "Save list of unused " & TypeOfTag$(TagType%) & " tags to..."
				DefFileName$ = LEFT(TypeOfTag$(TagType%), 4) & "Tags.txt"
				SaveFile$ = GETFILEBOX("Text files (*.TXT)|*.TXT", DialogTitle$, 1, DefFileName$, "txt", VenturaRoot$)

				IF SaveFile <> "" THEN
					SaveStatus = SaveToFile(SaveFile$)
					IF SaveStatus = TRUE THEN
						MESSAGE "Save successful"
					ELSE
						MESSAGE "Unable to save to " & CHR(13) & SaveFile$
					ENDIF
				ENDIF

			CASE UnusedTagsDialog.CancelButton.GetID()			
				UnusedTagsDialog.closedialog DIALOG_RETURN_CANCEL	

			CASE UnusedTagsDialog.TagsListBox.GetID()			'files list
				UnusedTagsDialog.SelectedTagsListBox.SetSelect 0

			CASE UnusedTagsDialog.SelectedTagsListBox.GetID()			'selected files list
				UnusedTagsDialog.TagsListBox.SetSelect 0
		END SELECT
		UnusedTagsDialog.TagsCountText.SetText UnusedTagsDialog.TagsListBox.GetItemCount()				'number of available files
		UnusedTagsDialog.SelectedTagsCountText.SetText UnusedTagsDialog.SelectedTagsListBox.GetItemCount()	'number of selected files
	ENDIF


	IF Event% = EVENT_DBL_MOUSE_CLICK THEN 		'mouse click
		SELECT CASE ControlID%
			CASE UnusedTagsDialog.TagsListBox.GetID()			'files list
				indx% = UnusedTagsDialog.TagsListBox.GetSelect()									'get index of selection
				UnusedTagsDialog.SelectedTagsListBox.AddItem UnusedTagsDialog.TagsListBox.GetItem(indx%)	'add selection to SelectedFilesList
				UnusedTagsDialog.TagsListBox.RemoveItem indx%										'remove selection from available files list
				IF indx% > UnusedTagsDialog.TagsListBox.GetItemCount() THEN
					UnusedTagsDialog.TagsListBox.SetSelect indx%-1
				ELSE
					UnusedTagsDialog.TagsListBox.SetSelect indx%
				ENDIF

			CASE UnusedTagsDialog.SelectedTagsListBox.GetID()			'selected files list
				indx% = UnusedTagsDialog.SelectedTagsListBox.GetSelect()								'get index of selection
				UnusedTagsDialog.TagsListBox.AddItem UnusedTagsDialog.SelectedTagsListBox.GetItem(indx%)	'add selection to FilesList
				UnusedTagsDialog.SelectedTagsListBox.RemoveItem indx%								'remove selection from selected files list
				IF indx% > UnusedTagsDialog.SelectedTagsListBox.GetItemCount() THEN
					UnusedTagsDialog.SelectedTagsListBox.SetSelect indx%-1
				ELSE
					UnusedTagsDialog.SelectedTagsListBox.SetSelect indx%
				ENDIF

		END SELECT
		UnusedTagsDialog.TagsCountText.SetText UnusedTagsDialog.TagsListBox.GetItemCount()				'number of available tags
		UnusedTagsDialog.SelectedTagsCountText.SetText UnusedTagsDialog.SelectedTagsListBox.GetItemCount()	'number of selected tags
	ENDIF
END SUB

 
 
' **************************************************************************************
' ShowFinish
' This function displays the finish dialog, showing a list of all tags selected for deletion.
'
' PARAMS:
'
' RETURNS: ShowFinish AS INTEGER - Integer indicating dialog return value(user selection)
'
' **************************************************************************************
FUNCTION ShowFinish%
DIM SelectedFilesIndex%
DIM ShowFinishRet%
DIM ShowFinishImage$

BEGIN DIALOG OBJECT ShowFinishDialog 290, 180, "Find Unused Tags Wizard", SUB ShowFinishDialogEventHandler
	PUSHBUTTON  135, 160, 46, 14, .BackButton, "< &Back"
	PUSHBUTTON  181, 160, 46, 14, .FinishButton, "&Delete"
	PUSHBUTTON  234, 160, 46, 14, .CancelButton, "&Exit"
	TEXT  95, 10, 179, 12, .InfoText, InfoText$
	TEXT  94, 127, 185, 12, .DeleteText, DeleteText$
	TEXT  95, 30, 80, 10, .ParaText, "Unused Paragraph Tags:"
	TEXT  185, 30, 90, 10, .ParaText2, "n of n selected for deletion"
	TEXT  95, 50, 80, 10, .CharText, "Unused Character tags:"
	TEXT  185, 50, 90, 10, .CharText2, "n of n selected for deletion"
	TEXT  95, 70, 80, 10, .FrameText, "Unused FrameTags:"
	TEXT  185, 70, 90, 10, .FrameText2, "n of n selected for deletion"
	IMAGE  10, 10, 75, 130, .ShowFinishImage
	GROUPBOX  10, 150, 270, 5, .LineGroupBox
END DIALOG

	ShowFinishDialog.SetStyle STYLE_INVISIBLE
	ShowFinishDialog.ShowFinishImage.SetImage "#LastBMP"
	ShowFinishDialog.ShowFinishImage.SetStyle STYLE_IMAGE_CENTERED
	ShowFinishDialog.DeleteText.SetStyle STYLE_SUNKEN
	
	ShowFinishRet% = Dialog(ShowFinishDialog)
	SELECT CASE ShowFinishRet%
		CASE DIALOG_RETURN_CANCEL 	
			STOP
		CASE DIALOG_RETURN_NEXT  
			ShowFinish = 1
		CASE DIALOG_RETURN_BACK 
			IF TagType% = PARA_TAG THEN      'back to char tags page
				ShowFinish = -1
			ELSE							'back to para tags page
				ShowFinish = -1
			ENDIF
	END SELECT
END FUNCTION


' **************************************************************************************
' ShowFinishDialogEventHandler
' This subroutine handles events for the finish dialog.
' PARAMS: BYVAL ControlID% - Integer indicating the dialog control that is generating a dialog event.
'		BYVAL Event% - Integer indicating the dialog event that has occurred in the dialog box
' **************************************************************************************
SUB ShowFinishDialogEventHandler(BYVAL ControlID%, BYVAL Event%)
	IF Event% = EVENT_INITIALIZATION THEN 		
		TotalUnusedTagsCount = SelectedUnusedParaTagsCount% + SelectedUnusedCharTagsCount% + SelectedUnusedFrameTagsCount% + SelectedUnusedRuleTagsCount%
		IF TotalUnusedTagsCount = 0 THEN
			InfoText$ = "No tags have been selected for deletion."
			DeleteText$ = ""
			ShowFinishDialog.FinishButton.Enable FALSE
		ELSEIF TotalUnusedTagsCount = 1 THEN
			InfoText$ = TotalUnusedTagsCount & " tag has been selected for deletion."
			DeleteText$ = "Select Delete to permanently remove the unused tag."
		ELSE
			InfoText$ = TotalUnusedTagsCount & " tags have been selected for deletion."
			DeleteText$ = "Select Delete to permanently remove the unused tags."
		ENDIF
		ShowFinishDialog.InfoText.SetText InfoText$
		ShowFinishDialog.DeleteText.SetText DeleteText$
		
		IF FindParaTag% THEN 
			ShowFinishDialog.ParaText.SetText "Unused Paragraph Tags:"
			IF UnusedParaTagsCount% < 1 AND SelectedUnusedParaTagsCount% < 1 THEN 
				ShowFinishDialog.ParaText2.SetText "No unused paragraph tags"
			ELSE
				ShowFinishDialog.ParaText2.SetText SelectedUnusedParaTagsCount% & " of " & UnusedParaTagsCount%+ SelectedUnusedParaTagsCount% & " selected for deletion"
			ENDIF
		ELSE
			ShowFinishDialog.ParaText.SetText ""
			ShowFinishDialog.ParaText2.SetText ""
		ENDIF

		IF FindCharTag% THEN 
			ShowFinishDialog.CharText.SetText "Unused Character Tags:"
			IF UnusedCharTagsCount% < 1 AND SelectedUnusedCharTagsCount% < 1 THEN 
				ShowFinishDialog.CharText2.SetText "No unused character tags"
			ELSE
				ShowFinishDialog.CharText2.SetText SelectedUnusedCharTagsCount% & " of " & UnusedCharTagsCount%+SelectedUnusedCharTagsCount% & " selected for deletion"
			ENDIF
		ELSE
			ShowFinishDialog.CharText.SetText ""
			ShowFinishDialog.CharText2.SetText ""
		ENDIF

		IF FindFrameTag% THEN 
			ShowFinishDialog.FrameText.SetText "Unused Frame Tags:"
			IF UnusedFrameTagsCount% < 1 AND SelectedUnusedFrameTagsCount% < 1 THEN 
				ShowFinishDialog.FrameText2.SetText "No unused frame tags"
			ELSE
				ShowFinishDialog.FrameText2.SetText SelectedUnusedFrameTagsCount% & " of " & UnusedFrameTagsCount%+SelectedUnusedFrameTagsCount% & " selected for deletion"
			ENDIF
		ELSE
			ShowFinishDialog.FrameText.SetText ""
			ShowFinishDialog.FrameText2.SetText ""
		ENDIF

		ShowFinishDialog.SetStyle STYLE_VISIBLE
	ENDIF

	IF Event% = EVENT_MOUSE_CLICK THEN 	
		SELECT CASE ControlID%
			CASE ShowFinishDialog.FinishButton.GetID()
				ShowFinishDialog.CloseDialog DIALOG_RETURN_NEXT
			CASE ShowFinishDialog.BackButton.GetID()
				ShowFinishDialog.CloseDialog DIALOG_RETURN_BACK
			CASE ShowFinishDialog.CancelButton.GetID()
				ShowFinishDialog.CloseDialog DIALOG_RETURN_CANCEL
		END SELECT
	ENDIF
END SUB


' **************************************************************************************
' SaveToFile
' This function removes all unused paragraph tags from the pub and redisplays the 
' paragraph tag dialog.
' 
' PARAMS:
'
' RETURNS: RemoveParaTags AS INTEGER - Integer indicating dialog return value(user selection)
' **************************************************************************************
FUNCTION SaveToFile(TagFile$) AS BOOLEAN
ON ERROR GOTO ErrorHandler
	CLOSE
	OPEN TagFile$ FOR APPEND AS 1

	SELECT CASE TagType%
		CASE PARA_TAG		'print list of unused paragraph tags to text file
			PRINT #1, "Unused Paragraph Tags:"
			FOR i%=1 TO UnusedParaTagsCount%
				PRINT #1, UnusedParaTags(i%)
			NEXT i%

		CASE CHAR_TAG		'print list of unused character tags to text file
			PRINT #1, "Unused Character Tags:"
			FOR i%=1 TO UnusedCharTagsCount%
				PRINT #1, UnusedCharTags(i%)
			NEXT i%

		CASE FRAME_TAG	'print list of unused frame tags to text file
			PRINT #1, "Unused Frame Tags:"
			FOR i%=1 TO UnusedFrameTagsCount%
				PRINT #1, UnusedFrameTags(i%)
			NEXT i%

	END SELECT
	CLOSE(1)
	SaveToFile = TRUE

EXIT FUNCTION
ErrorHandler:
	CLOSE
	SaveToFile = FALSE
END FUNCTION



' **************************************************************************************
' RemoveTags
' This function removes all unused tags from the pub.
' 
' PARAMS:
'
' RETURNS: RemoveParaTags AS INTEGER - Integer indicating dialog return value(user selection)
' **************************************************************************************
FUNCTION RemoveTags%(TagType%)
	WITHOBJECT OBJECT_VENTURA8

	SELECT CASE TagType%
		CASE PARA_TAG
			WHILE (SelectedUnusedParaTagsCount > 0)
				.ParaTagDelete SelectedUnusedParaTags(SelectedUnusedParaTagsCount)
				SelectedUnusedParaTags(SelectedUnusedParaTagsCount) = ""
				SelectedUnusedParaTagsCount = SelectedUnusedParaTagsCount - 1
			WEND

		CASE CHAR_TAG
			WHILE (SelectedUnusedCharTagsCount > 0)
				.CharacterTagDelete SelectedUnusedCharTags(SelectedUnusedCharTagsCount)
				SelectedUnusedCharTags(SelectedUnusedCharTagsCount) = ""
				SelectedUnusedCharTagsCount = SelectedUnusedCharTagsCount - 1
			WEND

		CASE FRAME_TAG
			WHILE (SelectedUnusedFrameTagsCount > 0)
				.FrameTagDelete SelectedUnusedFrameTags(SelectedUnusedFrameTagsCount)
				SelectedUnusedFrameTags(SelectedUnusedFrameTagsCount) = ""
				SelectedUnusedFrameTagsCount = SelectedUnusedFrameTagsCount - 1
			WEND

	END SELECT
	END WITHOBJECT
END FUNCTION





' **************************************************************************************
' FindParaTags
'
' **************************************************************************************
SUB FindParaTags()
DIM TagName$
DIM i%
	BEGINWAITCURSOR
	WITHOBJECT OBJECT_VENTURA8
		.SetVisible TRUE	'ShowVentura
		ParaTags%= .ParaTagCount()			
		FOR i%=1 TO ParaTags%
			TagName$ = .ParaTagGetAt(i)
			CreateListOfTags PARA_TAG, TagName$
		NEXT i%
	END WITHOBJECT
	ENDWAITCURSOR
END SUB


' **************************************************************************************
' FindCharTags
'
' **************************************************************************************
SUB FindCharTags()
DIM TagName$
DIM i%
	BEGINWAITCURSOR
	WITHOBJECT OBJECT_VENTURA8
		.SetVisible TRUE	'ShowVentura
		CharTags% = .CharacterTagCount()
		FOR i%=1 TO CharTags%
			TagName$ = .CharacterTagGetAt(i)
			CreateListOfTags CHAR_TAG, TagName$
		NEXT i%
	END WITHOBJECT
	ENDWAITCURSOR
END SUB



' **************************************************************************************
' FindFrameTags 
' This function finds unused frame tags
'
' **************************************************************************************
SUB FindFrameTags()
DIM TagName$
DIM i%
	BEGINWAITCURSOR
	WITHOBJECT OBJECT_VENTURA8
		.SetVisible TRUE	'ShowVentura
		FrameTags% = .FrameTagCount()
		FOR i%=1 TO FrameTags%
			TagName$ = .FrameTagGetAt(i)
			CreateListOfTags FRAME_TAG, TagName$
		NEXT i%
	END WITHOBJECT
	ENDWAITCURSOR
END SUB


' **************************************************************************************
' CreateListOfTags 
' This function finds unused paragraph, character, and frame tags
'
' PARAMS:TypeOfTag AS LONG - specifies the type of tag to look for
'						0 = ParaTags
'						1 = Character tags
'						2 = Frame tags
'	    TagName AS STRING -  Specifies the name of the tag to find
' **************************************************************************************
SUB CreateListOfTags(TypeOfTag&, NameOfTag AS STRING)
DIM Found AS BOOLEAN
Found=TRUE
	WITHOBJECT OBJECT_VENTURA8
		.EditInitFindText '.Reset=TRUE
		.EditInitFindTagOptions NameOfTag$, "",TypeOfTag& -1, FALSE, FALSE, TRUE	'TypeOfTag& -1 (since TypeOfTag is 0 based)
		Found = .EditFindTag()
		'IF tag isn't found, THEN it isn't used - so add it to the appropriate list (based on type)
		IF Found=FALSE THEN 
			SELECT CASE TypeOfTag&
				CASE PARA_TAG			'its a paragraph tag, make sure it is deletable
					'Body Text cannot be deleted
					IF UCASE(NameOfTag$) <> "BODY TEXT" THEN
						UnusedParaTagsCount = UnusedParaTagsCount + 1
						IF UnusedParaTagsCount% MOD MAXTAGS = 0 THEN 
							NewCnt% = UnusedParaTagsCount% + MAXTAGS
							REDIM PRESERVE UnusedParaTags$(NewCnt%)
							REDIM PRESERVE SelectedUnusedParaTags$(NewCnt%)
						ENDIF
						UnusedParaTags$(UnusedParaTagsCount) = NameOfTag$
					ENDIF
	
				CASE CHAR_TAG			'its a character tag, make sure it is deletable
					'Bold, Italic, Underline cannot be deleted
					IF UCASE(NameOfTag$) <> "BOLD" AND UCASE(NameOfTag$) <> "ITALIC" AND UCASE(NameOfTag$) <> "UNDERLINE" THEN
						UnusedCharTagsCount = UnusedCharTagsCount + 1 
						IF UnusedCharTagsCount% MOD MAXTAGS = 0 THEN 
							NewCnt% = UnusedCharTagsCount% + MAXTAGS
							REDIM PRESERVE UnusedCharTags$(NewCnt%)
							REDIM PRESERVE SelectedUnusedCharTags$(NewCnt%)
						ENDIF
						UnusedCharTags$(UnusedCharTagsCount) = NameOfTag$
					ENDIF

				CASE FRAME_TAG			'its a frame tag, make sure it is deletable
					'Default cannot be deleted
					IF UCASE(NameOfTag$) <> "DEFAULT FRAME" THEN
						UnusedFrameTagsCount = UnusedFrameTagsCount + 1 
						IF UnusedFrameTagsCount% MOD MAXTAGS = 0 THEN 
							NewCnt% = UnusedFrameTagsCount% + MAXTAGS
							REDIM PRESERVE UnusedFrameTags$(NewCnt%)
							REDIM PRESERVE SelectedUnusedFrameTags$(NewCnt%)
						ENDIF
						UnusedFrameTags$(UnusedFrameTagsCount) = NameOfTag$
					ENDIF

			END SELECT
		ENDIF
	END WITHOBJECT
END SUB



