REM TEACHING SCRIPT - Prints each page to separate file [CorelSCRIPT 8]
REM PrintOnePage.csc  February 5, 1998
REM  1998 Corel Corporation. All rights reserved.

REM ************************************************************************************
REM  This script prints the active Ventura publication to a file, one page at a time,
REM  using the default Ventura print style. To customize this script for your own 
REM  use, edit the predefined GLOBAL CONST variables that follow this comment.
REM  Note - There is no error checking implemented in this script. It is assumed that you
REM         have an open publication, and provide valid values for the variables.
REM *************************************************************************************

REM  Edit this value to reflect the name of the printer you wish to use.
GLOBAL CONST PRINTER_NAME$ = "HP LaserJet 4M Plus,LPT1:"	' Complete name and path of printer (get this from the Ventura print dialog, or by recording the .FilePRint command)

REM  Edit this value to specify the print style you wish to use.
GLOBAL CONST PRINT_STYLE$ = "CorelVentura 8.0 Defaults"	' Complete name and path of printer (get this from the Ventura print dialog, or by recording the .FilePRint command)

REM  Edit this value to specify the directory in which to place the print files.
GLOBAL CONST DEFAULT_DIRECTORY$ = "C:\Temp\"				' Directory in which to place Print files

REM  Edit this variable to specify the root name of the print file.
GLOBAL CONST PRINT_FILE$ = "PrintFile"					' Root name of print file (eg. PrintFile -> PrintFile1.prn)

' This section declares the subroutines used within the script
' Note - The EventHandler subroutine is not declared here, as it is defined after being called. 
DECLARE SUB GetPrintInfo		
DECLARE SUB PrintPub
DECLARE SUB PrintPages

' This section defines some values that will be used further down into the script
#DEFINE PRINT_SPECIFIED_PAGES		3				' Used by FilePrint command to indicate the range of pages to print
#DEFINE OBJECT_VENTURA "CorelVentura.Automation.8"	' For ease of porting to VP8

' Constants for Dialog Return Values
GLOBAL CONST DIALOG_RETURN_CANCEL% = 2
GLOBAL CONST DIALOG_RETURN_NEXT% = 3

' Constants for Dynamic Dialog Events
#DEFINE EVENT_INITIALIZATION   	0
#DEFINE EVENT_CHANGE_IN_CONTENT 	1
#DEFINE EVENT_MOUSE_CLICK      	2

' Constants for Dynamic Dialog Styles
#DEFINE STYLE_SUNKEN  &h0100

' Constants for print range
GLOBAL CONST PRINT_PUB% = 0	' variable indicating print range as entire publication
GLOBAL CONST PRINT_PAGE% = 1	' variable indicating print range as specified pages

' Global variables(need to be global to be used by Event Handler)
GLOBAL StartPage$	' the first page in range (used if pages is the selected range)
GLOBAL EndPage$	' the last page in range (used if pages is the selected range)
StartPage$="1"
EndPage$="1"

'//// MAIN //////////////////////////////////////////////////////////////////
GetPrintInfo



' **************************************************************************************
' PrintPub
' This subroutine prints the entire publication, one page at a time.
' PARAMS: None
' **************************************************************************************
SUB PrintPub
	WITHOBJECT OBJECT_VENTURA
		' Repeat for every chapter in the publication
		NumberOfChapters& = .ChapterCount()		' get the number of chapters
		FOR CurrentChapter& = 1 TO NumberOfChapters&
			' repeat for every page in the chapter
			NumberOfPages& = .ChapterPageCount()	' get the number of pages
			FOR CurrentPage& = 1 TO NumberOfPages&
				PrintFileName$ = DEFAULT_DIRECTORY$ & PRINT_FILE$ & CurrentPage& & ".prn"		' create a file name for the print file
				.FilePrint PRINT_SPECIFIED_PAGES, CurrentPage&, CurrentPage&, .PrinterName = PRINTER_NAME, .PrintToFile = PrintFileName$, .PrintStyleName = PRINT_STYLE
			NEXT CurrentPage&
		NEXT CurrentChapter&
	END WITHOBJECT
END SUB


' **************************************************************************************
' PrintPages
' This subroutine prints the specified range of pages, one page at a time.
' PARAMS: None
' **************************************************************************************
SUB PrintPages
	WITHOBJECT OBJECT_VENTURA
		' repeat for the specified range of pages
		FOR CurrentPage& = INT(StartPage$) TO INT(EndPage$)
			PrintFileName$ = DEFAULT_DIRECTORY$ & PRINT_FILE$ & CurrentPage& & ".prn"		' create a file name for the print file
			.FilePrint PRINT_SPECIFIED_PAGES, CurrentPage&, CurrentPage&, .PrinterName = PRINTER_NAME, .PrintToFile = PrintFileName$, .PrintStyleName = PRINT_STYLE
		NEXT CurrentPage&
	END WITHOBJECT
END SUB


' **************************************************************************************
' GetPrintInfo
' This subroutine displays the PrintInfo dialog and obtains the range of pages to be printed.
' PARAMS: None
' **************************************************************************************
SUB GetPrintInfo
' this section (from BEGIN to END DIALOG) defines the dialog, but does not show it or enable it.
BEGIN DIALOG OBJECT PrintInfoDialog 200, 125, "Page Print Wizard", SUB PrintInfoDialogEventHandler
	OPTIONGROUP .PrintRangeOptionGroup%
		OPTIONBUTTON  25, 39, 60, 10, .PublicationOptionButton, "Pu&blication"
		OPTIONBUTTON  25, 55, 50, 10, .PagesOptionButton, "Pa&ges"
	TEXT  105, 40, 20, 10, .Text3, "&Start:"	 ' position label before control to enable accelerator key
	TEXTBOX  132, 38, 35, 13, .StartPageText
	TEXT  105, 56, 20, 10, .Text4, "&End:"	 	 ' position label before control to enable accelerator key
	TEXTBOX  132, 54, 35, 13, .EndPageText
	TEXT  13, 81, 25, 10, .Text6, "&Printer:"
	PUSHBUTTON  176, 79, 14, 14, .HelpButton, "?"
	PUSHBUTTON  89, 107, 46, 14, .OKButton, "OK"
	PUSHBUTTON  144, 107, 46, 14, .CancelButton, "Cancel"
	TEXT  10, 5, 180, 20, .Text1, "This script prints the active Ventura publication, one page at a time."
	GROUPBOX  10, 25, 180, 48, .GroupBox1, "Print Range:"
	TEXT  45, 80, 132, 12, .PrinterText, PRINTER_NAME$
	GROUPBOX  8, 99, 182, 5, .GroupBox2
END DIALOG

	' this section enables the dialog 
	PrintInfoDialog.PrinterText.SetStyle STYLE_SUNKEN	' set text displaying printer to sunken (for appearance purposes only)
	PrintInfoRet% = DIALOG(PrintInfoDialog)			' show the print info dialog
	SELECT CASE PrintInfoRet% 
		CASE DIALOG_RETURN_CANCEL 		' dialog return is Cancel, so stop script execution
			STOP
		CASE DIALOG_RETURN_NEXT			' dialog return is OK, so continue script execution
			PrintRange& = PrintInfoDialog.PrintRangeOptionGroup.GetValue()
			IF PrintRange& = PRINT_PUB THEN 
				PrintPub				' user selected to print entire publication
			ELSE
				PrintPages			' user selected to print a range of pages
			ENDIF
	END SELECT
END SUB


' **************************************************************************************
' PrintInfoDialogEventHandler
' This subroutine handles events for the PrintInfo dialog.
' PARAMS: BYVAL ControlID% - Integer indicating the dialog control that is generating a dialog event.
'		BYVAL Event% - Integer indicating the dialog event that has occurred in the dialog box
' **************************************************************************************
SUB PrintInfoDialogEventHandler(BYVAL ControlID%, BYVAL Event%)
	' initialize dialog controls, disabling the start and end page controls, unless user selects to print a page range
	IF Event% = EVENT_INITIALIZATION THEN
		PrintRange& = PrintInfoDialog.PrintRangeOptionGroup.GetValue()
		IF PrintRange& = PRINT_PUB THEN 
			PrintInfoDialog.StartPageText.Enable FALSE
			PrintInfoDialog.EndPageText.Enable FALSE
			PrintInfoDialog.Text3.Enable FALSE
			PrintInfoDialog.Text4.Enable FALSE
		ELSE
			PrintInfoDialog.StartPageText.Enable TRUE
			PrintInfoDialog.EndPageText.Enable TRUE
			PrintInfoDialog.StartPageText.SetText StartPage$
			PrintInfoDialog.EndPageText.SetText EndPage$
			PrintInfoDialog.Text3.Enable TRUE
			PrintInfoDialog.Text4.Enable TRUE
		ENDIF
	ENDIF
	
	' obtain values for start and end page controls if user enters values in them (only valid if enabled)
	IF Event% = EVENT_CHANGE_IN_CONTENT THEN
		SELECT CASE ControlID%
			CASE PrintInfoDialog.StartPageText.GetID()
				StartPage$ = PrintInfoDialog.StartPageText.GetText()
			CASE PrintInfoDialog.EndPageText.GetID()
				EndPage$ = PrintInfoDialog.EndPageText.GetText()
		END SELECT
	ENDIF

	' respond to user mouse-clicking on a control 
	IF Event% = EVENT_MOUSE_CLICK THEN
		SELECT CASE ControlID%
			CASE PrintInfoDialog.CancelButton.GetID()
				PrintInfoDialog.CloseDialog DIALOG_RETURN_CANCEL
			CASE PrintInfoDialog.OKButton.GetID()
				StartPage$ = PrintInfoDialog.StartPageText.GetText()
				IF StartPage$ = "" THEN StartPage$ = "0"
				EndPage$ = PrintInfoDialog.EndPageText.GetText()
				IF EndPage$ = "" THEN EndPage$ = StartPage$
				PrintInfoDialog.CloseDialog DIALOG_RETURN_NEXT
			CASE PrintInfoDialog.HelpButton.GetID()
				MESSAGE "To specify a different printer, edit the script."
		END SELECT
		' disable the start and end page controls, unless user selects to print a page range in which case the controls are enabled	
		PrintRange& = PrintInfoDialog.PrintRangeOptionGroup.GetValue()
		IF PrintRange& = PRINT_PUB THEN 
			PrintInfoDialog.StartPageText.Enable FALSE
			PrintInfoDialog.EndPageText.Enable FALSE
			PrintInfoDialog.Text3.Enable FALSE
			PrintInfoDialog.Text4.Enable FALSE
		ELSE
			PrintInfoDialog.StartPageText.Enable TRUE
			PrintInfoDialog.EndPageText.Enable TRUE
			PrintInfoDialog.StartPageText.SetText StartPage$
			PrintInfoDialog.EndPageText.SetText EndPage$
			PrintInfoDialog.Text3.Enable TRUE
			PrintInfoDialog.Text4.Enable TRUE
		ENDIF
	ENDIF
END SUB

