REM Creates sample tags [CorelSCRIPT 8]
REM TagSampler.csc March, 1998
REM  1998 Corel Corporation. All rights reserved.

REM **************************************************************************************
REM This script creates a sample of all tags in the active publication. A sample of text
REM tagged with each style is output to a new page in the current publication. The sample
REM text that is displayed can be specified by the user in the Wizard dialog.
REM **************************************************************************************

' Create a temporary folder to provide a path for the include files
'  -this enables the include files to be located 
#addfol "..\..\Scripts"
#include "ScpConst.csi"
#include "VPConst.csi"

' Embed bitmaps if script is to be compiled into exe or csb formats
' -this will eliminate the need to include these files
#ADDRESBMP IntroBMP "Bitmaps\IntroBMP.bmp"

'Constants for Dialog Return Values
GLOBAL CONST DIALOG_RETURN_CANCEL% = 2
GLOBAL CONST DIALOG_RETURN_NEXT% = 3
GLOBAL CONST DIALOG_RETURN_BACK% = 4
GLOBAL CONST DIALOG_RETURN_BROWSE% = 5

'/////FUNCTION & SUBROUTINE DECLARATIONS/////////////////////////////////////////////////
DECLARE SUB RegQuery()
DECLARE FUNCTION ShowIntro() AS INTEGER
DECLARE FUNCTION ShowTagList() AS INTEGER
DECLARE FUNCTION CreateSamples() AS INTEGER

'/////GLOBAL VARIABLES & CONSTANTS////////////////////////////////////////////////////////
GLOBAL VenturaRoot$		'Root directory of Ventura from registry
GLOBAL SampleText$		'Sample text string

'/////LOCAL DECLARATIONS//////////////////////////////////////////////////////////////////
CONST MAXSTEP% = 2		'maximum number of pages in the Wizard
DIM DialogReturn%		'identifies user's selection for next step in Wizard
DIM NextStep%			'specifies which page appears next in the Wizard


' **************************************************************************************
' MAIN
' **************************************************************************************
ON ERROR GOTO ErrorHandler

RegQuery										'get root directory where Ventura is installed
SampleText$ = "Sample of paragraph tags"			'initialize sample text string

NextStep% = 1
DO
	SELECT CASE NextStep%
		CASE 1: DialogReturn% = ShowIntro()		'show intro dialog
		CASE 2: DialogReturn% = ShowTagList()		'display samples of tags
	END SELECT
	NextStep% = NextStep% + DialogReturn%
LOOP UNTIL NextStep% = MAXSTEP + 1

ExitScript:
STOP

ErrorHandler:
SELECT CASE ErrNum
	CASE 800
		MESSAGE "FATAL ERROR" & CHR(13) & "Script will now exit."
		RESUME AT ExitScript
	CASE ELSE
		MESSAGE "ERROR: " & STR(ErrNum) & CHR(13) & "Script will now exit."
		RESUME AT ExitScript
	END SELECT


' *******************************************************************************
' RegQuery
' This subroutine queries the Registry to determine the root directory where 
' Ventura is installed.
' *******************************************************************************
SUB RegQuery
ON ERROR GOTO ErrorHandler

	'get Ventura config directory
	VentDir$ = REGISTRYQUERY(HKEY_LOCAL_MACHINE,VENTURA_REGQUERY_CONST,"ConfigDir") 	
	
	'isolate Ventura root directory from Ventura config directory
	first% = 1
	pos% = 1
	DO WHILE first <> 0
	    first = INSTR(VentDir$, "\", first )
	    IF first <> 0 THEN
	        pos = first
	        first = first + 1
	    END IF
	LOOP
	VenturaRoot$ = LEFT(VentDir$, pos - 1) 	'root directory where Ventura is installed

EXIT SUB
ErrorHandler:
	MESSAGE "Error reading registry:" & CHR(13) & RegString$
	ErrNum = 800
END SUB


' *******************************************************************************
' ShowIntro
' This function displays the introduction dialog.
' 
' PARAMS: None
'
' RETURNS: ShowIntro AS INTEGER - Integer indicating dialog return value.
' *******************************************************************************
FUNCTION ShowIntro%
BEGIN DIALOG OBJECT IntroDialog 290, 180, "Tag Preview Wizard", SUB IntroDialogEventHandler
	PUSHBUTTON  181, 160, 46, 14, .NextButton, "&Next >"
	CANCELBUTTON  234, 160, 46, 14, .CancelButton
	PUSHBUTTON  135, 160, 46, 14, .BackButton, "< &Back"
	TEXT  95, 10, 185, 20, .Text2, "This Wizard allows you to preview the formatting assigned to paragraph tags in the selected publication."
	IMAGE  10, 10, 75, 130, .IntroImage
	GROUPBOX  10, 150, 270, 5, .LineGroupBox
	TEXT  95, 40, 185, 20, .Text5, "To begin, click Next."
END DIALOG

	IntroDialog.IntroImage.SetImage "#IntroBMP"
	IntroDialog.IntroImage.SetStyle STYLE_IMAGE_CENTERED

	IntroRet%=DIALOG(IntroDialog)
	IF IntroRet% = DIALOG_RETURN_CANCEL THEN STOP			
	IF IntroRet% = DIALOG_RETURN_NEXT THEN ShowIntro = 1		
END FUNCTION

' *******************************************************************************
' IntroDialogEventHandler
' This subroutine responds to user interface with the introduction dialog.
' 
' PARAMS: BYVAL ControlID% - Integer indicating the dialog control that is 
'                            generating a dialog event.
'		BYVAL Event% - Integer indicating the dialog event that has occurred.
' *******************************************************************************
SUB IntroDialogEventHandler(BYVAL ControlID%, BYVAL Event%)
	IF Event% = EVENT_INITIALIZATION THEN 		
		IntroDialog.BackButton.Enable FALSE 
	ENDIF
	IF Event% = EVENT_MOUSE_CLICK THEN 	
		SELECT CASE ControlID%
			CASE IntroDialog.NextButton.GetID()
				BEGINWAITCURSOR
				WITHOBJECT OBJECT_VENTURA8
				ENDWAITCURSOR
					'Make sure there is an open pub
					IF .CountWindows() = 0 THEN
						PubMsg$ = "You need an open publication to run this script." & CHR(13) & "Open one now?"
						MsgVal% = MESSAGEBOX(PubMsg$, "WARNING", MB_YES_NO OR MB_STOP_ICON)
						IF MsgVal% = MSG_YES THEN 		'Yes, open a pub
							SETCURRFOLDER VenturaRoot$
							PubName$ = GETFILEBOX("Publication files (*.VP*)|*.VP*", , , ,"*.vp*", VenturaRoot$ & "\Ventura\Samples" )
							IF PubName$ <> "" THEN
								.SetVisible TRUE
								.FileOpen PubName$, , TRUE, 1, TRUE, FALSE
								IntroDialog.closedialog DIALOG_RETURN_NEXT
							ENDIF
						ELSE
							'STOP
						ENDIF
					ELSE
						IntroDialog.closedialog DIALOG_RETURN_NEXT
					ENDIF
				END WITHOBJECT
			CASE IntroDialog.CancelButton.GetID()
				IntroDialog.CloseDialog DIALOG_RETURN_CANCEL
		END SELECT
	ENDIF
END FUNCTION


' *******************************************************************************
' ShowTagList
' This function displays a dialog containing a list of all tags in the active 
' publication. The user is prompted to select those tags for which samples are to 
' be displayed. The user has the option to modify the sample text displayed by
' entering a new text string at this point.
' 
' PARAMS: None
'
' RETURNS: ShowTagList AS INTEGER - Integer indicating dialog return value.
' *******************************************************************************
FUNCTION ShowTagList%

BEGIN DIALOG OBJECT ShowTagListDialog 290, 180, "Tag Preview Wizard", SUB ShowTagListDialogEventHandler
	TEXT  10, 18, 80, 11, .Text3, "A&vailable tags:"
	LISTBOX  10, 30, 100, 100, .TagsListBox
	PUSHBUTTON  122, 33, 46, 14, .SelectButton, "&Select >>"
	PUSHBUTTON  122, 49, 46, 14, .DeselectButton, "<< &Deselect"
	PUSHBUTTON  123, 95, 46, 14, .SelectAllButton, "Select &All"
	PUSHBUTTON  123, 112, 46, 14, .DeselectAllButton, "D&eselect All"
	TEXT  180, 18, 80, 11, .Text4, "S&elected tags:"
	LISTBOX  180, 30, 100, 100, .SampleTagsListBox
	TEXT  10, 135, 46, 12, .Text2, "Sample &text:"
	TEXTBOX  60, 135, 220, 13, .SampleTextBox
	PUSHBUTTON  135, 160, 46, 14, .BackButton, "< &Back"
	PUSHBUTTON  181, 160, 46, 14, .FinishButton, "&Finish"
	CANCELBUTTON  234, 160, 46, 14, .CancelButton
	TEXT  10, 5, 270, 12, .Text1, "Which tags would you like to preview?"
	GROUPBOX  10, 150, 270, 5, .LineGroupBox
	TEXT  89, 18, 20, 11, .TagsCount, ""
	TEXT  260, 18, 20, 11, .SampleTagsCount, ""
END DIALOG

	ShowTagListDialog.SetStyle STYLE_INVISIBLE
	ShowTagListDialog.TagsListBox.SetStyle STYLE_SORTING			
	ShowTagListDialog.SampleTagsListBox.SetStyle STYLE_SORTING	

	ShowTagListRet% = Dialog(ShowTagListDialog)
	SELECT CASE ShowTagListRet%
		CASE DIALOG_RETURN_CANCEL 	
			STOP
		CASE DIALOG_RETURN_NEXT  	
			ShowTagList = 1
		CASE DIALOG_RETURN_BACK 	
			ShowTagList = -1
	END SELECT
END FUNCTION

' *******************************************************************************
' ShowTagListDialogEventHandler
' This subroutine responds to user interface with the progress dialog.
' 
' PARAMS:  ControlID% - identifies which dialog control to respond to.
'	      Event% - identifies which event to respond to (ie. mouse click, etc.).
' *******************************************************************************
SUB ShowTagListDialogEventHandler(BYVAL ControlID%, BYVAL Event%)
	IF Event% = EVENT_INITIALIZATION THEN 		'mouse click
		ShowTagListDialog.SampleTextBox.SetText SampleText$
		BEGINWAITCURSOR
		WITHOBJECT OBJECT_VENTURA8
		ENDWAITCURSOR
			ParaTags%= .ParaTagCount()			
			FOR i%=1 TO ParaTags%
				ShowTagListDialog.TagsListBox.AddItem .ParaTagGetAt(i)
			NEXT i%
		END WITHOBJECT
		ShowTagListDialog.TagsCount.SetStyle STYLE_RIGHT_JUSTIFY			
		ShowTagListDialog.SampleTagsCount.SetStyle STYLE_RIGHT_JUSTIFY	
		ShowTagListDialog.TagsCount.SetText ShowTagListDialog.TagsListBox.GetItemCount()			'number of available tags
		ShowTagListDialog.SampleTagsCount.SetText ShowTagListDialog.SampleTagsListBox.GetItemCount()	'number of selected tags
		ShowTagListDialog.SetStyle STYLE_VISIBLE
	ENDIF

	IF Event% = EVENT_CHANGE_IN_CONTENT THEN 	
 		SampleText$ = ShowTagListDialog.SampleTextBox.GetText()
	ENDIF

	IF Event% = EVENT_MOUSE_CLICK THEN 	
		SELECT CASE ControlID%
			CASE ShowTagListDialog.FinishButton.GetID()
				WITHOBJECT OBJECT_VENTURA8
					.ViewGoToPage 1, , 2, 0
					.PageFirstLine
					.PageInsertPages , 1, 1, TRUE
					.ViewGoToPage 1, , 2, 0
					.PageFirstLine
					SampleCount% = ShowTagListDialog.SampleTagsListBox.GetItemCount()
					FOR i% = 1 TO SampleCount%
						.FormatSetParaTag ShowTagListDialog.SampleTagsListBox.GetItem(i%)
						.TypeText SampleText$ & CHR(10)
					NEXT i%
				END WITHOBJECT
				ShowTagListDialog.CloseDialog DIALOG_RETURN_NEXT
			CASE ShowTagListDialog.BackButton.GetID()
				ShowTagListDialog.CloseDialog DIALOG_RETURN_BACK
			CASE ShowTagListDialog.CancelButton.GetID()
				ShowTagListDialog.CloseDialog DIALOG_RETURN_CANCEL

			CASE ShowTagListDialog.SelectButton.GetID()			
				indx% = ShowTagListDialog.TagsListBox.GetSelect()									
				IF indx%=0 THEN	'no tags selected
					IF ShowTagListDialog.TagsListBox.GetItemCount() = 0 THEN
						MESSAGE "There are no tags available for selection."
					ELSE
						MESSAGE "Please select a tag from the available tags list."
					ENDIF
				ELSE
					ShowTagListDialog.SampleTagsListBox.AddItem ShowTagListDialog.TagsListBox.GetItem(indx%)	'add selection to SelectedtagsList
					ShowTagListDialog.TagsListBox.RemoveItem indx%									'remove selection from available tags list
					IF indx% > ShowTagListDialog.TagsListBox.GetItemCount() THEN
						ShowTagListDialog.TagsListBox.SetSelect indx%-1
					ELSE
						ShowTagListDialog.TagsListBox.SetSelect indx%
					ENDIF
					ShowTagListDialog.SampleTagsListBox.SetSelect 0
				ENDIF

			CASE ShowTagListDialog.DeselectButton.GetID()			
				indx% = ShowTagListDialog.SampleTagsListBox.GetSelect()								'get index of selection
				IF indx%=0 THEN	'no tags selected
					IF ShowTagListDialog.SampleTagsListBox.GetItemCount() = 0 THEN
						MESSAGE "There are no tags available for deselection"
					ELSE
						MESSAGE "Please select a tag from the selected tags list."
					ENDIF
				ELSE
					ShowTagListDialog.TagsListBox.AddItem ShowTagListDialog.SampleTagsListBox.GetItem(indx%)	'add selection to tagsList
					ShowTagListDialog.SampleTagsListBox.RemoveItem indx%								'remove selection from selected tags list
					IF indx% > ShowTagListDialog.SampleTagsListBox.GetItemCount() THEN
						ShowTagListDialog.SampleTagsListBox.SetSelect indx%-1
					ELSE
						ShowTagListDialog.SampleTagsListBox.SetSelect indx%
					ENDIF
					ShowTagListDialog.TagsListBox.SetSelect 0
				ENDIF

			CASE ShowTagListDialog.SelectAllButton.GetID()		
				ShowTagListDialog.SampleTagsListBox.SetSelect 0
				WHILE ShowTagListDialog.TagsListBox.GetItemCount() > 0				'while there are available tags
					ShowTagListDialog.SampleTagsListBox.AddItem ShowTagListDialog.TagsListBox.GetItem(1)	'add selection to SelectedtagsList
					ShowTagListDialog.TagsListBox.RemoveItem 1									'remove selection from available tags list	
				WEND

			CASE ShowTagListDialog.DeselectAllButton.GetID()		
				ShowTagListDialog.TagsListBox.SetSelect 0
				WHILE ShowTagListDialog.SampleTagsListBox.GetItemCount() > 0		'while there are selected tags
					ShowTagListDialog.TagsListBox.AddItem ShowTagListDialog.SampleTagsListBox.GetItem(1)	'add selection to tagsList
					ShowTagListDialog.SampleTagsListBox.RemoveItem 1								'remove selection from selected tags list
				WEND
		END SELECT
		ShowTagListDialog.TagsCount.SetText ShowTagListDialog.TagsListBox.GetItemCount()				'number of available tags
		ShowTagListDialog.SampleTagsCount.SetText ShowTagListDialog.SampleTagsListBox.GetItemCount()		'number of selected tags
	ENDIF

	IF Event% = EVENT_DBL_MOUSE_CLICK THEN 	
		SELECT CASE ControlID%
			CASE ShowTagListDialog.TagsListBox.GetID()			
				indx% = ShowTagListDialog.TagsListBox.GetSelect()									'get index of selection
				ShowTagListDialog.SampleTagsListBox.AddItem ShowTagListDialog.TagsListBox.GetItem(indx%)	'add selection to SelectedtagsList
				ShowTagListDialog.TagsListBox.RemoveItem indx%									'remove selection from available tags list
				IF indx% > ShowTagListDialog.TagsListBox.GetItemCount() THEN
					ShowTagListDialog.TagsListBox.SetSelect indx%-1
				ELSE
					ShowTagListDialog.TagsListBox.SetSelect indx%
				ENDIF
			CASE ShowTagListDialog.SampleTagsListBox.GetID()			
				indx% = ShowTagListDialog.SampleTagsListBox.GetSelect()							'get index of selection
				ShowTagListDialog.TagsListBox.AddItem ShowTagListDialog.SampleTagsListBox.GetItem(indx%)	'add selection to tags List
				ShowTagListDialog.SampleTagsListBox.RemoveItem indx%								'remove selection from selected tags list
				IF indx% > ShowTagListDialog.SampleTagsListBox.GetItemCount() THEN
					ShowTagListDialog.SampleTagsListBox.SetSelect indx%-1
				ELSE
					ShowTagListDialog.SampleTagsListBox.SetSelect indx%
				ENDIF
		END SELECT
		ShowTagListDialog.TagsCount.SetText ShowTagListDialog.TagsListBox.GetItemCount()				'number of available tags
		ShowTagListDialog.SampleTagsCount.SetText ShowTagListDialog.SampleTagsListBox.GetItemCount()		'number of selected tags
	ENDIF

	IF ShowTagListDialog.SampleTagsListBox.GetItemCount() = 0 THEN 
		ShowTagListDialog.FinishButton.Enable FALSE
	ELSE
		ShowTagListDialog.FinishButton.Enable TRUE
	ENDIF	
END SUB



